@@ -1,6 +1,6 @@
 #Global variables
 configfolder="/home/user/.SleepAnalyser/" #users home dir with ending /
-logfolder="/home/user/MyDocs/SleepAnalyser/" #users log dir with ending /
+defaultlogfolder="/home/user/MyDocs/SleepAnalyser/" #users log dir with ending /
 ConfigFile="SleepAnalyser.conf"
 #development PC:
 devconfigfolder="/home/gruinelli/Maemo/SleepAnalyser/"
@@ -33,6 +33,7 @@ debug=0
 test=0
 logfilename=""
 logfile=""
+logfolder=""
 lastlogfile=""
 Note=""
 Header=""
