@@ -60,6 +60,7 @@ def main():
         print "Runs not on a N900 => Use randomizer for acceleration sensor data"
         data.configfolder=data.devconfigfolder
         data.logfolder=data.devlogfolder
+    else: data.logfolder=data.defaultlogfolder
 
     app = QtGui.QApplication(sys.argv)
     
@@ -80,7 +81,6 @@ def main():
     
     #get user name for in log files
     if(data.user==""):
-#            tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
         text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
                                                                                              "It will be used in the records file, this makes it easier\n" + \
                                                                                              "when you want to share your sleep pattern with others.")
@@ -244,6 +244,7 @@ class frmStartWindow(QtGui.QWidget):
             self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
 
 
+
     ###########################################################################
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
@@ -279,6 +280,9 @@ class frmStartWindow(QtGui.QWidget):
     def ShowViewWindow(self):
         global ViewWindowGraph
         
+        #reset to default log folder
+        if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
+        else: data.logfolder=data.defaultlogfolder
         if os.path.exists(data.logfolder+data.lastlogfile):
             data.logfilename=data.lastlogfile
         else:
@@ -287,14 +291,17 @@ class frmStartWindow(QtGui.QWidget):
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
             else: #no logfiles in logfolder, show "open file" dialog
-                tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+#                tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+                tmp=ViewWindow.ShowFileDialog()
+                if(tmp==""): return #only continue if valid log file selected
                 tmp2=tmp.split("/")
                 l=len(tmp2)    
-                x=tmp2[l-1]
-                if(x==""): return #only continue if valid log file selected
-                data.logfilename=x
+                data.logfilename=tmp2[l-1]
+                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
+                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+#                data.logfilename=x
         
-        print data.logfilename
+#        print data.logfilename
         
         ViewWindowGraph = ViewWindowCanvas()
         ViewWindow.ShowLogFile()
@@ -334,7 +341,6 @@ class frmStartWindow(QtGui.QWidget):
 
 
 
-
 ###########################################################################
 #  Class for Collecting Window
 ###########################################################################
@@ -532,7 +538,9 @@ class frmViewWindow(QtGui.QWidget):
 
 
     def ShowLogFile(self):
-        OpenLogFile()    
+        r=OpenLogFile()    
+        if(r==1): #file too long            
+            QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
         LoadFileList()
         ProcessData()
         data.Xscale=1 #default zoom level
@@ -590,29 +598,42 @@ class frmViewWindow(QtGui.QWidget):
         
 
     def DeleteLogFile(self):
-        reply = QtGui.QMessageBox.question(self, 'Delete Logfile?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
 
-            LoadFileList()
             l=len(data.arrLogFiles)
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
             else: #no logfiles in logfolder, show "open file" dialog
-                x=self.ShowFileDialog()
-                if(x==""): 
+#                x=self.ShowFileDialog()
+#                if(x==""): 
+#                    self.closeEvent("") #no file selected, close
+#                    return
+#                data.logfilename=x
+                tmp=self.ShowFileDialog()
+                if(tmp==""): #only continue if valid log file selected
                     self.closeEvent("") #no file selected, close
                     return
-                data.logfilename=x
+                tmp2=tmp.split("/")
+                l=len(tmp2)    
+                data.logfilename=tmp2[l-1]
+                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
+                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+            LoadFileList()
             self.ShowLogFile()
 
 
 
     def Open(self):
-        x=self.ShowFileDialog()
-        if(x==""):  return
-        data.logfilename=x
+        tmp=self.ShowFileDialog()
+        if(tmp==""): return #only continue if valid log file selected
+        tmp2=tmp.split("/")
+        l=len(tmp2)    
+        data.logfilename=tmp2[l-1]
+        data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
+        print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         self.ShowLogFile()
     
     
@@ -620,10 +641,12 @@ class frmViewWindow(QtGui.QWidget):
     
     def ShowFileDialog(self):
         tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
-        tmp2=tmp.split("/")
-        l=len(tmp2)    
-        x=tmp2[l-1]
-        return x
+        print "Selected file:",  tmp
+#        tmp2=tmp.split("/")
+#        l=len(tmp2)    
+#        x=tmp2[l-1]
+#        return x
+        return tmp
 
 
     def closeEvent(self, event):
